==> plantuml-libs-5.2.0.tgz: package/distribution/azure-4/Item/AppServices/ServiceAppServicePlans.md <==
# ServiceAppServicePlans


```text
azure-4/Item/AppServices/ServiceAppServicePlans
```

```text
include('azure-4/Item/AppServices/ServiceAppServicePlans')
```



| Illustration | ServiceAppServicePlans | ServiceAppServicePlansCard | ServiceAppServicePlansGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/AppServices/ServiceAppServicePlans.png) | ![illustration for ServiceAppServicePlans](../../../azure-4/Item/AppServices/ServiceAppServicePlans.Local.png) | ![illustration for ServiceAppServicePlansCard](../../../azure-4/Item/AppServices/ServiceAppServicePlansCard.Local.png) | ![illustration for ServiceAppServicePlansGroup](../../../azure-4/Item/AppServices/ServiceAppServicePlansGroup.Local.png) |




## ServiceAppServicePlans

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAppServicePlans
include('azure-4/Item/AppServices/ServiceAppServicePlans')

' renders the element
ServiceAppServicePlans('ServiceAppServicePlans', 'Service App Service Plans', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAppServicePlans
include('azure-4/Item/AppServices/ServiceAppServicePlans')

' renders the element
ServiceAppServicePlans('ServiceAppServicePlans', 'Service App Service Plans', 'an optional tech label')
@enduml
```

## ServiceAppServicePlansCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAppServicePlansCard
include('azure-4/Item/AppServices/ServiceAppServicePlans')

' renders the element
ServiceAppServicePlansCard('ServiceAppServicePlansCard', 'Service App Service Plans Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAppServicePlansCard
include('azure-4/Item/AppServices/ServiceAppServicePlans')

' renders the element
ServiceAppServicePlansCard('ServiceAppServicePlansCard', 'Service App Service Plans Card', 'an optional description')
@enduml
```

## ServiceAppServicePlansGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAppServicePlansGroup
include('azure-4/Item/AppServices/ServiceAppServicePlans')

' renders the element
ServiceAppServicePlansGroup('ServiceAppServicePlansGroup', 'Service App Service Plans Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAppServicePlansGroup
include('azure-4/Item/AppServices/ServiceAppServicePlans')

' renders the element
ServiceAppServicePlansGroup('ServiceAppServicePlansGroup', 'Service App Service Plans Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/azure-4/Item/AppServices/ServiceAppServicePlans.md <==
# ServiceAppServicePlans


```text
azure-4/Item/AppServices/ServiceAppServicePlans
```

```text
include('azure-4/Item/AppServices/ServiceAppServicePlans')
```



| Illustration | ServiceAppServicePlans | ServiceAppServicePlansCard | ServiceAppServicePlansGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/AppServices/ServiceAppServicePlans.png) | ![illustration for ServiceAppServicePlans](../../../azure-4/Item/AppServices/ServiceAppServicePlans.Local.png) | ![illustration for ServiceAppServicePlansCard](../../../azure-4/Item/AppServices/ServiceAppServicePlansCard.Local.png) | ![illustration for ServiceAppServicePlansGroup](../../../azure-4/Item/AppServices/ServiceAppServicePlansGroup.Local.png) |




## ServiceAppServicePlans

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAppServicePlans
include('azure-4/Item/AppServices/ServiceAppServicePlans')

' renders the element
ServiceAppServicePlans('ServiceAppServicePlans', 'Service App Service Plans', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAppServicePlans
include('azure-4/Item/AppServices/ServiceAppServicePlans')

' renders the element
ServiceAppServicePlans('ServiceAppServicePlans', 'Service App Service Plans', 'an optional tech label')
@enduml
```

## ServiceAppServicePlansCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAppServicePlansCard
include('azure-4/Item/AppServices/ServiceAppServicePlans')

' renders the element
ServiceAppServicePlansCard('ServiceAppServicePlansCard', 'Service App Service Plans Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAppServicePlansCard
include('azure-4/Item/AppServices/ServiceAppServicePlans')

' renders the element
ServiceAppServicePlansCard('ServiceAppServicePlansCard', 'Service App Service Plans Card', 'an optional description')
@enduml
```

## ServiceAppServicePlansGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAppServicePlansGroup
include('azure-4/Item/AppServices/ServiceAppServicePlans')

' renders the element
ServiceAppServicePlansGroup('ServiceAppServicePlansGroup', 'Service App Service Plans Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceAppServicePlansGroup
include('azure-4/Item/AppServices/ServiceAppServicePlans')

' renders the element
ServiceAppServicePlansGroup('ServiceAppServicePlansGroup', 'Service App Service Plans Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
